@@ -8,7 +8,7 @@
  * Graphs are composed of nodes, edges, and nested subgraphs.
  * These graph objects may be attributed with string name-value pairs
  * and programmer-defined records (see Attributes).
- * All of Libcgraph’s global symbols have the prefix **ag** (case varying).
+ * Most of Libcgraph’s global symbols have the prefix **ag** (case varying).
  * In the following, if a function has a parameter `int createflag` and
  * the object does not exist, the function will create the specified object
  * if `createflag` is non-zero; otherwise, it will return NULL.
@@ -241,7 +241,7 @@ struct Agobj_s {
 /** @brief This is the node struct allocated per graph (or subgraph).
 
 It resides in the n_dict of the graph.
-The node set is maintained by libcdt, but transparently to libgraph callers.
+The node set is maintained by libcdt, but transparently to libcgraph callers.
 Every node may be given an optional string name at its time of creation,
 or it is permissible to pass NULL for the name. */
 
@@ -291,12 +291,12 @@ struct Agdesc_s {         /* graph descriptor */
 
 /** @defgroup cgraph_disc disciplines
  *  @ingroup cgraph_misc
- *  @brief disciplines for external resources needed by libgraph
+ *  @brief disciplines for external resources needed by libcgraph
  *
  *  (This section is not intended for casual users.)
  *
  *  Programmer-defined disciplines customize certain resources:
- *  ID namespace, memory, and I/O - needed by Libcgraph.
+ *  ID namespace and I/O - needed by Libcgraph.
  *  A discipline struct (or NULL) is passed at graph creation time.
  *  @{
  */
@@ -441,7 +441,7 @@ CGRAPH_API Agraph_t *agopen(char *name, Agdesc_t desc, Agdisc_t *disc);
  * A strict graph cannot have multi-edges or self-arcs.
  *
  * @param disc - discipline structure which can be used
- * to tailor I/O, memory allocation, and ID allocation. Typically, a NULL
+ * to tailor I/O and ID allocation. Typically, a NULL
  * value will be used to indicate the default discipline @ref AgDefaultDisc.
  */
 
@@ -564,16 +564,6 @@ CGRAPH_API int agobjkind(void *obj);
  * All uses of cgraph strings need to be freed using @ref agstrfree
  * in order to correctly maintain the reference count.
  *
- * @ref agcanonStr returns a pointer to a version of the input string
- * canonicalized for output for later re-parsing.
- * This includes quoting special characters and keywords.
- * It uses its own internal buffer, so the value will be lost on
- * the next call to @ref agcanonStr.
- * @ref agcanon is identical with @ref agcanonStr
- * except it can be used with any character string.
- * The second argument indicates whether or not the string
- * should be canonicalized as an HTML-like string.
- *
  * @{
  */
 CGRAPH_API char *agstrdup(Agraph_t *, const char *);
@@ -609,7 +599,6 @@ CGRAPH_API char *agstrbind_html(Agraph_t *g, const char *);
 CGRAPH_API int agstrfree(Agraph_t *, const char *, bool is_html);
 ///< @param is_html Is the string being freed an HTML-like string?
 CGRAPH_API char *agstrcanon(char *, char *);
-CGRAPH_API char *agcanonStr(char *str); /* manages its own buf */
 /// @}
 
 /** @defgroup cgraph_attr attributes
